@@ -37,8 +37,6 @@ ChangeRecorder::ChangeRecorder( ChangeRecorderPrivate *privateclass, QObject * p
 
 ChangeRecorder::~ChangeRecorder()
 {
-  Q_D( ChangeRecorder );
-  d->saveNotifications();
 }
 
 void ChangeRecorder::setConfig(QSettings * settings)
@@ -49,7 +47,8 @@ void ChangeRecorder::setConfig(QSettings * settings)
     Q_ASSERT( d->pendingNotifications.isEmpty() );
     d->loadNotifications();
   } else if ( d->settings ) {
-    d->saveNotifications();
+    if ( d->enableChangeRecording )
+      d->saveNotifications();
     d->settings = settings;
   }
 }
@@ -59,13 +58,16 @@ void ChangeRecorder::replayNext()
   Q_D( ChangeRecorder );
   if ( !d->pendingNotifications.isEmpty() ) {
     const NotificationMessage msg = d->pendingNotifications.head();
-    // TODO kDebug() << msg;
-    if ( d->ensureDataAvailable( msg ) )
+    if ( d->ensureDataAvailable( msg ) ) {
       d->emitNotification( msg );
-    else if ( !d->translateAndCompress( d->pipeline, msg ) ) {
+    } else if ( d->translateAndCompress( d->pipeline, msg ) ) {
+      // The msg is now in both pipeline and pendingNotifications.
+      // When data is available, MonitorPrivate::flushPipeline will emitNotification.
+      // When changeProcessed is called, we'll finally remove it from pendingNotifications.
+    } else {
       // In the case of a move where both source and destination are
       // ignored, we ignore the message and process the next one.
-      d->pendingNotifications.dequeue();
+      d->dequeueNotification();
       return replayNext();
     }
   } else {
@@ -74,7 +76,6 @@ void ChangeRecorder::replayNext()
     // will be stuck forever in the ResourceScheduler.
     emit nothingToReplay();
   }
-  d->saveNotifications();
 }
 
 bool ChangeRecorder::isEmpty() const
@@ -86,16 +87,12 @@ bool ChangeRecorder::isEmpty() const
 void ChangeRecorder::changeProcessed()
 {
   Q_D( ChangeRecorder );
-  if ( !d->pendingNotifications.isEmpty() )
-    d->pendingNotifications.dequeue();
 
-  // SLOW! After loading 8000 notifications and processing one, we save back the 7999 remaining
-  // ones, and then process the next one etc.
-  // Testcase: mark 8000 emails as read.
-  // TODO: Reserve 4 bytes at the beginning of the file, for the number of the next change
-  // that must be processed. In the loading code, skip everything until that number.
-  // Do a full-save only once the notifications list is empty (or only once in a while).
-  d->saveNotifications();
+  // changerecordertest.cpp calls changeProcessed after receiving nothingToReplay,
+  // so test for emptiness. Not sure real code does this though.
+  // Q_ASSERT( !d->pendingNotifications.isEmpty() )
+  if ( !d->pendingNotifications.isEmpty() )
+    d->dequeueNotification();
 }
 
 void ChangeRecorder::setChangeRecordingEnabled( bool enable )
@@ -104,8 +101,12 @@ void ChangeRecorder::setChangeRecordingEnabled( bool enable )
   if ( d->enableChangeRecording == enable )
     return;
   d->enableChangeRecording = enable;
-  if ( !enable )
+  if ( enable ) {
+    d->m_needFullSave = true;
+    d->notificationsLoaded();
+  } else {
     d->dispatchNotifications();
+  }
 }
 
 QString Akonadi::ChangeRecorder::dumpNotificationListToString() const
