@@ -43,7 +43,6 @@
 #include "trashrestorejob.h"
 #include "entitydeletedattribute.h"
 #include "recentcollectionaction_p.h"
-#include "kdsignalblocker.h"
 
 #include <KAction>
 #include <KActionCollection>
@@ -194,7 +193,8 @@ class StandardActionManager::Private
       collectionSelectionModel( 0 ),
       itemSelectionModel( 0 ),
       favoritesModel( 0 ),
-      favoriteSelectionModel( 0 )
+      favoriteSelectionModel( 0 ),
+      insideSelectionSlot( false )
     {
       actions.fill( 0, StandardActionManager::LastType );
 
@@ -522,14 +522,31 @@ class StandardActionManager::Private
       }
     }
 
+    // RAII class for setting insideSelectionSlot to true on entering, and false on exiting, the two slots below.
+    class InsideSelectionSlotBlocker {
+    public:
+    InsideSelectionSlotBlocker( Private *p ) : _p( p ) {
+      Q_ASSERT( !p->insideSelectionSlot );
+      p->insideSelectionSlot = true;
+    }
+    ~InsideSelectionSlotBlocker() {
+      Q_ASSERT( _p->insideSelectionSlot );
+      _p->insideSelectionSlot = false;
+    }
+    private:
+      Private *_p;
+    };
+
     void collectionSelectionChanged()
     {
+      if ( insideSelectionSlot )
+        return;
+      InsideSelectionSlotBlocker block( this );
       QItemSelection selection = collectionSelectionModel->selection();
       selection = mapToEntityTreeModel( collectionSelectionModel->model(), selection );
       selection = mapFromEntityTreeModel( favoritesModel, selection );
 
       if ( favoriteSelectionModel ) {
-        KDSignalBlocker blocker(q);
         favoriteSelectionModel->select( selection, QItemSelectionModel::ClearAndSelect );
       }
 
@@ -538,16 +555,20 @@ class StandardActionManager::Private
 
     void favoriteSelectionChanged()
     {
+      if ( insideSelectionSlot )
+        return;
       QItemSelection selection = favoriteSelectionModel->selection();
-      if ( selection.indexes().isEmpty() )
+      if ( selection.isEmpty() )
         return;
 
       selection = mapToEntityTreeModel( favoritesModel, selection );
       selection = mapFromEntityTreeModel( collectionSelectionModel->model(), selection );
 
-      KDSignalBlocker blocker(q);
+      InsideSelectionSlotBlocker block( this );
       collectionSelectionModel->select( selection, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
-      blocker.unblock();
+
+      // Also set the current index. This will trigger KMMainWidget::slotFolderChanged in kmail, which we want.
+      collectionSelectionModel->setCurrentIndex( selection.indexes().first(), QItemSelectionModel::NoUpdate );
 
       updateActions();
     }
@@ -812,7 +833,7 @@ class StandardActionManager::Private
                                                                                     : collection.name();
 
       CollectionPropertiesDialog* dlg = new CollectionPropertiesDialog( collection, mCollectionPropertiesPageNames, parentWidget );
-      dlg->setCaption( contextText( StandardActionManager::CollectionProperties, StandardActionManager::DialogTitle ).arg( displayName ) );
+      dlg->setCaption( contextText( StandardActionManager::CollectionProperties, StandardActionManager::DialogTitle,displayName ) );
       dlg->show();
     }
 
@@ -1160,7 +1181,7 @@ class StandardActionManager::Private
     {
       if ( job->error() ) {
         KMessageBox::error( parentWidget,
-                            contextText( StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageText ).arg( job->errorString() ),
+                            contextText( StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageText, job->errorString() ),
                             contextText( StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageTitle ) );
       }
     }
@@ -1169,7 +1190,7 @@ class StandardActionManager::Private
     {
       if ( job->error() ) {
         KMessageBox::error( parentWidget,
-                            contextText( StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageText ).arg( job->errorString() ),
+                            contextText( StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageText, job->errorString() ),
                             contextText( StandardActionManager::DeleteCollections, StandardActionManager::ErrorMessageTitle ) );
       }
     }
@@ -1178,7 +1199,7 @@ class StandardActionManager::Private
     {
       if ( job->error() ) {
         KMessageBox::error( parentWidget,
-                            contextText( StandardActionManager::MoveCollectionsToTrash, StandardActionManager::ErrorMessageText ).arg( job->errorString() ),
+                            contextText( StandardActionManager::MoveCollectionsToTrash, StandardActionManager::ErrorMessageText, job->errorString() ),
                             contextText( StandardActionManager::MoveCollectionsToTrash, StandardActionManager::ErrorMessageTitle ) );
       }
     }
@@ -1187,7 +1208,7 @@ class StandardActionManager::Private
     {
       if ( job->error() ) {
         KMessageBox::error( parentWidget,
-                            contextText( StandardActionManager::MoveItemsToTrash, StandardActionManager::ErrorMessageText ).arg( job->errorString() ),
+                            contextText( StandardActionManager::MoveItemsToTrash, StandardActionManager::ErrorMessageText, job->errorString() ),
                             contextText( StandardActionManager::MoveItemsToTrash, StandardActionManager::ErrorMessageTitle ) );
       }
     }
@@ -1196,7 +1217,7 @@ class StandardActionManager::Private
     {
       if ( job->error() ) {
         KMessageBox::error( parentWidget,
-                            contextText( StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageText ).arg( job->errorString() ),
+                            contextText( StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageText, job->errorString() ),
                             contextText( StandardActionManager::DeleteItems, StandardActionManager::ErrorMessageTitle ) );
       }
     }
@@ -1205,7 +1226,7 @@ class StandardActionManager::Private
     {
       if ( job->error() ) {
         KMessageBox::error( parentWidget,
-                            contextText( StandardActionManager::CreateResource, StandardActionManager::ErrorMessageText ).arg( job->errorString() ),
+                            contextText( StandardActionManager::CreateResource, StandardActionManager::ErrorMessageText, job->errorString() ),
                             contextText( StandardActionManager::CreateResource, StandardActionManager::ErrorMessageTitle ) );
       }
     }
@@ -1214,7 +1235,7 @@ class StandardActionManager::Private
     {
       if ( job->error() ) {
         KMessageBox::error( parentWidget,
-                            contextText( StandardActionManager::Paste, StandardActionManager::ErrorMessageText ).arg( job->errorString() ),
+                            contextText( StandardActionManager::Paste, StandardActionManager::ErrorMessageText, job->errorString() ),
                             contextText( StandardActionManager::Paste, StandardActionManager::ErrorMessageTitle ) );
       }
     }
@@ -1392,12 +1413,22 @@ class StandardActionManager::Private
       return contextTexts[ type ].value( context ).text;
     }
 
+    QString contextText( StandardActionManager::Type type, StandardActionManager::TextContext context, const QString& value ) const
+    {
+      KLocalizedString text = contextTexts[ type ].value( context ).localizedText;
+      if ( text.isEmpty() )
+        return contextTexts[ type ].value( context ).text;
+ 
+      return text.subs( value ).toString();
+    }
+
+
     QString contextText( StandardActionManager::Type type, StandardActionManager::TextContext context, int count, const QString &value ) const
     {
-      if ( contextTexts[ type ].value( context ).localizedText.isEmpty() )
+      KLocalizedString text = contextTexts[ type ].value( context ).localizedText;
+      if ( text.isEmpty() )
         return contextTexts[ type ].value( context ).text;
 
-      KLocalizedString text = contextTexts[ type ].value( context ).localizedText;
       const QString str = text.subs( count ).toString();
       const int argCount = str.count( QRegExp( QLatin1String( "%[0-9]" ) ) );
       if ( argCount > 0 ) {
@@ -1414,6 +1445,7 @@ class StandardActionManager::Private
     QItemSelectionModel *itemSelectionModel;
     FavoriteCollectionsModel *favoritesModel;
     QItemSelectionModel *favoriteSelectionModel;
+    bool insideSelectionSlot;
     QVector<KAction*> actions;
     QHash<StandardActionManager::Type, KLocalizedString> pluralLabels;
     QHash<StandardActionManager::Type, KLocalizedString> pluralIconLabels;
