@@ -34,6 +34,7 @@
 #include <KDE/KMessageBox>
 #include <KDE/KPushButton>
 #include <KDE/KUrl>
+#include <KDE/KImageIO>
 
 #include <QtCore/QBuffer>
 #include <QtCore/QDateTime>
@@ -552,19 +553,17 @@ void TextEditPrivate::_k_slotAddEmoticon( const QString& text)
 
 void TextEditPrivate::_k_slotAddImage()
 {
-  QPointer<KFileDialog> fdlg = new KFileDialog( QString(), QString(), q );
+  QStringList mimetypes = KImageIO::mimeTypes( KImageIO::Reading );
+  QPointer<KFileDialog> fdlg = new KFileDialog( QString(), mimetypes.join(QLatin1String(" ")), q );
   fdlg->setOperationMode( KFileDialog::Other );
   fdlg->setCaption( i18n( "Add Image" ) );
   fdlg->okButton()->setGuiItem( KGuiItem( i18n( "&Add" ), QLatin1String( "document-open" ) ) );
   fdlg->setMode( KFile::Files );
-  if ( fdlg->exec() != KDialog::Accepted ) {
-    delete fdlg;
-    return;
-  }
-
-  const KUrl::List files = fdlg->selectedUrls();
-  foreach ( const KUrl &url, files ) {
-    q->addImage( url );
+  if ( fdlg->exec() == KDialog::Accepted && fdlg ) {
+    const KUrl::List files = fdlg->selectedUrls();
+    foreach ( const KUrl &url, files ) {
+      q->addImage( url );
+    }
   }
   delete fdlg;
 }
